compare_shadow_including_dom_positions

Function compare_shadow_including_dom_positions 

fn compare_shadow_including_dom_positions(
    no_gc: &NoGC,
    container_a: &Node,
    offset_a: u32,
    container_b: &Node,
    offset_b: u32,
) -> Ordering
Compare two shadow-including DOM positions by first projecting them into a shared root and then comparing the two positions. This function assumes that the two positions share a Document.