project_into_shared_tree

Function project_into_shared_tree 

fn project_into_shared_tree<'a>(
    no_gc: &'a NoGC,
    container_a: &Node,
    offset_a: u32,
    target: Option<&Node>,
) -> (UnrootedDom<'a, Node>, u32)
Project the position given by container_a and offset_a into a root that also contains target. If target is not supplied then project the position into the Document root.

This does something very similar to GetComposedRanges, but doesn’t have special handling for start and end nodes.