struct FlatTreeSelection<'no_gc> {
no_gc: &'no_gc NoGC,
start: FlatTreeBoundary<'no_gc>,
end: FlatTreeBoundary<'no_gc>,
}Fields
no_gc: &'no_gc NoGCstart: FlatTreeBoundary<'no_gc>end: FlatTreeBoundary<'no_gc>Implementations
Sourceimpl<'no_gc> FlatTreeSelection<'no_gc>
impl<'no_gc> FlatTreeSelection<'no_gc>
Sourcefn from_selection_if_renderable(
no_gc: &'no_gc NoGC,
selection: &Selection,
) -> Option<Self>
fn from_selection_if_renderable( no_gc: &'no_gc NoGC, selection: &Selection, ) -> Option<Self>
Get the FlatTreeSelection for this Selection, returning None if the Selection
doesn’t have a range or if that flat tree range is unrenderable (for instance, because one
or both of the endpoints is not in the flat tree).
fn range_for_character_data( &self, character_data: &CharacterData, ) -> RangeAny<Utf32CodeUnits>
fn traversal(&self) -> VisibleSelectionTraversal<'no_gc> ⓘ