Selection

Struct Selection 

#[repr(C)]
pub(crate) struct Selection { reflector_: Reflector, document: Dom<Document>, range: DomRefCell<Option<SelectionRange>>, live_range: MutNullableDom<Range>, visible_range: DomRefCell<Option<SelectionRange>>, direction: Cell<Direction>, has_scheduled_selectionchange_event: Cell<bool>, visible_selection_dirty: Cell<bool>, }
Fields

reflector_: Reflectordocument: Dom<Document>range: DomRefCell<Option<SelectionRange>>

A range that holds the start and end of this selection, which may potentially cross shadow roots.

live_range: MutNullableDom<Range>

The live range version of this selection, which will never cross shadow roots.

visible_range: DomRefCell<Option<SelectionRange>>

This is like Range, but in the flat tree, which means that:

  • It is None if the selection is unrenderable.
  • Boundaries are in flat tree order.
direction: Cell<Direction>

The Direction of this Selection which determines which endpoint of Self::range is the anchor and which is the focus.

has_scheduled_selectionchange_event: Cell<bool>visible_selection_dirty: Cell<bool>

Whether or not this Selection needs to remark DOM nodes with selection flags after a change to its underlying Range.

Implementations

Source

impl Selection

Source

impl Selection

Source

impl Selection

fn new_inherited(document: &Document) -> Selection

pub(crate) fn new(cx: &mut JSContext, document: &Document) -> DomRoot<Selection>

pub(crate) fn visible_selection_dirty(&self) -> bool

fn clear_cached_live_range(&self)

pub(crate) fn clear_selection_if_live_range_document_changed( &self, no_gc: &NoGC, range: &Range, ) -> bool

Clear this entire Selection if the Document of its live range has changed or its boundaries are no longer connected. Returns true if the selection was cleared or false otherwise.

pub(crate) fn set_start_or_end_from_live_range( &self, no_gc: &NoGC, start_or_end: StartOrEnd, live_range: &Range, ) -> bool

Update the start of end boundary of this Selection based on a change to the given associated Range. While the behavior here isn’t totally specified yet, it follows other browsers. If the change would change the direction of the Selection it is collapsed at the newly-set boundary.

pub(crate) fn update_from_live_range( &self, no_gc: &NoGC, live_range: &Range, notification: SelectionLiveRangeNotification, )

fn set_range(&self, _no_gc: &NoGC, new_range: Option<SelectionRange>) -> bool

pub(crate) fn set_live_range(&self, no_gc: &NoGC, new_range: Option<&Range>)

fn selection_boundaries_changed(&self)

fn iter_nodes_with_overlaps_document_selection_flag<'no_gc>( &self, no_gc: &'no_gc NoGC, ) -> impl Iterator<Item = UnrootedDom<'no_gc, Node>>

fn set_visible_range(&self, flat_tree_selection: Option<FlatTreeSelection<'_>>)

pub(crate) fn update_overlaps_document_selection_flags(&self, no_gc: &NoGC)

pub(crate) fn queue_selectionchange_task(&self)

fn is_in_composed_tree_of_document_and_is_not_ua_widget( &self, node: &Node, ) -> bool

pub(crate) fn start_boundary(&self, cx: &mut JSContext) -> (DomRoot<Node>, u32)

pub(crate) fn end_boundary(&self, cx: &mut JSContext) -> (DomRoot<Node>, u32)

fn assert_valid_selection(&self, no_gc: &NoGC)

fn assert_valid_selection_and_live_range(&self, no_gc: &NoGC)

pub(crate) fn active_range(&self, cx: &mut JSContext) -> Option<DomRoot<Range>>

https://w3c.github.io/editing/docs/execCommand/#active-range

The active range is the range of the selection given by calling getSelection() on the context object. (Thus the active range may be null.)

pub(crate) fn expect_active_range(&self, cx: &mut JSContext) -> DomRoot<Range>

pub(crate) fn set_visible_selection_dirty(&self)

fn composed_anchor_position(&self) -> Option<(DomRoot<Node>, u32)>

fn live_anchor_node(&self, cx: &mut JSContext) -> Option<DomRoot<Node>>

fn live_anchor_offset(&self, cx: &mut JSContext) -> u32

fn live_focus_node(&self, cx: &mut JSContext) -> Option<DomRoot<Node>>

fn live_focus_offset(&self, cx: &mut JSContext) -> u32

pub(crate) fn insert_steps(&self, parent: &Node, child: &Node, count: u32)

https://dom.spec.whatwg.org/#concept-node-insert steps 5.1-5.2 and https://dom.spec.whatwg.org/#move steps 17.1-17.2 adapted for selections.

pub(crate) fn pre_remove_steps( &self, removed_node: &Node, parent_of_removed_node: &Node, index_of_removed_node: &mut dyn FnMut() -> u32, )

pub(crate) fn normalization_steps( &self, parent: &Node, node: &Node, current_node: &Node, current_node_index: &dyn Fn() -> u32, length: u32, )

https://dom.spec.whatwg.org/#dom-node-normalize Steps 6.1-6.4 adapted for selections.

  • parent: The parent of both other node arguments.
  • node: The node that text is being merged into.
  • current_node: The node which has text being merged into node and will be removed from the DOM.
  • length: The length of the text content that was merged into node from siblings before current_node.
pub(crate) fn replace_data_steps( &self, node: &Node, offset: u32, removed_code_units: u32, added_code_units: &mut dyn FnMut() -> u32, )

https://dom.spec.whatwg.org/#concept-cd-replace steps 8-11 adapted for selections.

pub(crate) fn text_split_steps( &self, node: &Node, offset: u32, parent_node: &Node, new_node: &Node, )

https://dom.spec.whatwg.org/#concept-text-split steps 7.2-7.3 adapted for selections.

pub(crate) fn collapse_to_dom_position( &self, cx: &mut JSContext, container: &Node, offset: Utf32CodeUnitsOrNodeOffset, )

pub(crate) fn collapse_or_extend_to_dom_position( &self, cx: &mut JSContext, container: &Node, offset: Utf32CodeUnitsOrNodeOffset, )