struct VisibleSelectionFlagUpdate<'no_gc> {
no_gc: &'no_gc NoGC,
previously_flagged_nodes: FxHashSet<UnrootedDom<'no_gc, Node>>,
used_user_select_cache: FxHashMap<UnrootedDom<'no_gc, Node>, UsedUserSelect>,
needs_new_display_list: bool,
}Fields
no_gc: &'no_gc NoGCpreviously_flagged_nodes: FxHashSet<UnrootedDom<'no_gc, Node>>The nodes that previously had the OVERLAPS_DOCUMENT_SELECTION set on them before this flag update.
Hash keys are pointer addresses which are not directly controlled by web content
so we don’t need HashDoS resistance and can use a faster hasher than std’s default
used_user_select_cache: FxHashMap<UnrootedDom<'no_gc, Node>, UsedUserSelect>Cache shared between calls to Node::used_user_select
needs_new_display_list: boolWhether or not this update requires a display list update.
Implementations
Sourceimpl<'no_gc> VisibleSelectionFlagUpdate<'no_gc>
impl<'no_gc> VisibleSelectionFlagUpdate<'no_gc>
fn run( no_gc: &'no_gc NoGC, previously_flagged_nodes: FxHashSet<UnrootedDom<'no_gc, Node>>, flat_tree_selection: Option<&FlatTreeSelection<'_>>, document: &Document, )
fn set( &mut self, node: &UnrootedDom<'no_gc, Node>, flat_tree_selection: &FlatTreeSelection<'_>, )
fn clear(&mut self, node: &Node)
fn set_character_data_selection( &mut self, character_data: &CharacterData, range: Option<RangeAny<Utf32CodeUnits>>, )
fn set_node_selection( &mut self, node: &Node, flat_tree_selection: Option<&FlatTreeSelection<'_>>, )
fn finish(self, document: &Document)